@@ -143,10 +143,15 @@ class CreateRecTaskRequest(AbstractModel):
         :type EngineModelType: str
         :param ChannelNum: 语音声道数。1：单声道；2：双声道（仅支持 8k_zh 引擎模型）。
         :type ChannelNum: int
-        :param ResTextFormat: 识别结果返回形式。0： 识别结果文本(含分段时间戳)； 1：词级别粒度的[详细识别结果](https://cloud.tencent.com/document/api/1093/37824#SentenceDetail)(不含标点，含语速值)；2：词级别粒度的详细识别结果（包含标点）
+        :param ResTextFormat: 识别结果返回形式。0： 识别结果文本(含分段时间戳)； 1：词级别粒度的[详细识别结果](https://cloud.tencent.com/document/api/1093/37824#SentenceDetail)(不含标点，含语速值)；2：词级别粒度的详细识别结果（包含标点、语速值）
         :type ResTextFormat: int
         :param SourceType: 语音数据来源。0：语音 URL；1：语音数据（post body）。
         :type SourceType: int
+        :param SpeakerDiarization: 是否开启话者分离，0：不开启，1：开启(仅支持8k_zh/16k_zh引擎模型，单声道音频)
+        :type SpeakerDiarization: int
+        :param SpeakerNumber: 话者分离人数（需配合开启话者分离使用），支持2-10（8k_zh仅支持2， 16k_zh支持2-10）
+注：话者分离目前是beta版本，请根据您的需要谨慎使用
+        :type SpeakerNumber: int
         :param CallbackUrl: 回调 URL，用户自行搭建的用于接收识别结果的服务器地址， 长度小于2048字节。如果用户使用回调方式获取识别结果，需提交该参数；如果用户使用轮询方式获取识别结果，则无需提交该参数。
         :type CallbackUrl: str
         :param Url: 语音的URL地址，需要公网可下载。长度小于2048字节，当 SourceType 值为 0 时须填写该字段，为 1 时不需要填写。注意：请确保录音文件时长在5个小时之内，否则可能识别失败。请保证文件的下载速度，否则可能下载失败。
@@ -165,11 +170,6 @@ class CreateRecTaskRequest(AbstractModel):
         :type ConvertNumMode: int
         :param Extra: 附加参数
         :type Extra: str
-        :param SpeakerDiarization: 是否开启话者分离，0：不开启，1：开启(仅支持8k_zh/16k_zh引擎模型，单声道音频)
-        :type SpeakerDiarization: int
-        :param SpeakerNumber: 话者分离人数（需配合开启话者分离使用），支持2-10（8k_zh仅支持2， 16k_zh支持2-10）
-注：话者分离目前是beta版本，请根据您的需要谨慎使用
-        :type SpeakerNumber: int
         :param FilterPunc: 是否过滤标点符号（目前支持中文普通话引擎）。 0：不过滤，1：过滤句末标点，2：过滤所有标点。默认为0。
         :type FilterPunc: int
         """
@@ -177,6 +177,8 @@ class CreateRecTaskRequest(AbstractModel):
         self.ChannelNum = None
         self.ResTextFormat = None
         self.SourceType = None
+        self.SpeakerDiarization = None
+        self.SpeakerNumber = None
         self.CallbackUrl = None
         self.Url = None
         self.Data = None
@@ -186,8 +188,6 @@ class CreateRecTaskRequest(AbstractModel):
         self.FilterModal = None
         self.ConvertNumMode = None
         self.Extra = None
-        self.SpeakerDiarization = None
-        self.SpeakerNumber = None
         self.FilterPunc = None
 
 
@@ -196,6 +196,8 @@ class CreateRecTaskRequest(AbstractModel):
         self.ChannelNum = params.get("ChannelNum")
         self.ResTextFormat = params.get("ResTextFormat")
         self.SourceType = params.get("SourceType")
+        self.SpeakerDiarization = params.get("SpeakerDiarization")
+        self.SpeakerNumber = params.get("SpeakerNumber")
         self.CallbackUrl = params.get("CallbackUrl")
         self.Url = params.get("Url")
         self.Data = params.get("Data")
@@ -205,8 +207,6 @@ class CreateRecTaskRequest(AbstractModel):
         self.FilterModal = params.get("FilterModal")
         self.ConvertNumMode = params.get("ConvertNumMode")
         self.Extra = params.get("Extra")
-        self.SpeakerDiarization = params.get("SpeakerDiarization")
-        self.SpeakerNumber = params.get("SpeakerNumber")
         self.FilterPunc = params.get("FilterPunc")
 
 
